@@ -42,7 +42,7 @@ def run_local_optimizer(d,x0,x_defl = []):
         worker = d.workers["walkers"][(int(i - ((i // number_of_walkers) * number_of_walkers)))]
         data = {"d":bf,"x0":x0[i],"x_defl":x_defl}
         tasks.append(client.submit(local_method,data,workers = worker))
-        print("local optimizer submitted to worker ", worker," ; method: ", d.local_optimizer)
+        print("HGDL says: local optimizer submitted to worker ", worker," ; method: ", d.local_optimizer)
     results = client.gather(tasks)
     number_of_walkers = len(tasks)
     x = np.empty((number_of_walkers, dim))
@@ -56,15 +56,16 @@ def run_local_optimizer(d,x0,x_defl = []):
         for j in range(i):
             #exchange for function def too_close():
             if np.linalg.norm(np.subtract(x[i],x[j])) < 2.0 * d.radius and success[j] == True:
-                print("CAUTION: points too close to each other; point removed")
+                print("CAUTION: points too close to each other in HGDL; point removed")
                 success[j] = False; break
         for j in range(len(x_defl)):
             if np.linalg.norm(np.subtract(x[i],x_defl[j])) < 2.0 * d.radius\
             and grad_norm[i] < 1e-5:
-                print("CAUTION: local method converged to deflated position")
+                print("CAUTION: local method converged to deflated position in HGDL")
                 success[i] = False
                 print(x[i],x_defl[j])
                 print(grad_norm[i])
+                print("--")
     return x, f, grad_norm, eig, success
 ###########################################################################
 
